//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: DOMTreeProcessingTest.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//

/*
 * DOMTreeProcessingTest.java
 * JUnit based test
 *
 * Created on December 17, 2001, 12:59 PM
 */                

package siena.xml.tests;

import siena.xml.DOMTreeProcessing;
import junit.framework.*;
import org.w3c.dom.Node;
import org.w3c.dom.Attr;
import org.w3c.dom.NodeList;
import org.w3c.dom.NamedNodeMap;
import org.apache.xerces.dom.CoreDocumentImpl;

/**
 *
 * @author CorliC
 */                                
public class DOMTreeProcessingTest extends TestCase {

    private CoreDocumentImpl document = null;
    
    public DOMTreeProcessingTest(java.lang.String testName) {
        super(testName);
    }        
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(DOMTreeProcessingTest.class);
        
        return suite;
    }
    
    protected void setUp() throws Exception {
        super.setUp();
        document = new CoreDocumentImpl();
    }
    
    /** Test of findChildByName method, of class siena.xml.DOMTreeProcessing. */
    public void testFindChildByName() {
        Node parent = document.createElementNS("","Parent");

	System.out.println(" - Test: DOMTreeProcessing - findChildByName method");
        parent.appendChild(document.createElementNS("","Child1"));
        parent.appendChild(document.createElementNS("","Child2"));
        parent.appendChild(document.createElementNS("","Child3"));
        parent.appendChild(document.createElementNS("","Child4"));
        parent.appendChild(document.createElementNS("","Child5"));
        
        Assert.assertNotNull("Could not find the first child node.", DOMTreeProcessing.findChildByName("Child1",parent));
        Assert.assertNotNull("Could not find the second child node.", DOMTreeProcessing.findChildByName("Child2",parent));
        Assert.assertNotNull("Could not find the third child node.", DOMTreeProcessing.findChildByName("Child3",parent));
        Assert.assertNotNull("Could not find the forth child node.", DOMTreeProcessing.findChildByName("Child4",parent));
        Assert.assertNotNull("Could not find the fifth child node.", DOMTreeProcessing.findChildByName("Child5",parent));

        Assert.assertNull("Found the wrong child.", DOMTreeProcessing.findChildByName("Child6", parent));

        parent = document.createElementNS("","Parent");
        Assert.assertNull("Found a child when there were no children.", DOMTreeProcessing.findChildByName("Child1", parent));        
    }
    
    /** Test of countSameTagSiblings method, of class siena.xml.DOMTreeProcessing. */
    public void testCountSameTagSiblings() {
        int count = 0;
        Node temp = null;        
        Node parent = document.createElementNS("","Parent");
        Node middleChild = document.createElementNS("","middle");
	
	System.out.println(" - Test: DOMTreeProcessing - countSameTagSiblings method");

        parent.appendChild(document.createElementNS("","Child1"));
        parent.appendChild(document.createElementNS("","Child2"));
        parent.appendChild(document.createElementNS("","Child1"));
        parent.appendChild(middleChild);
        parent.appendChild(document.createElementNS("","Child2"));
        parent.appendChild(document.createElementNS("","Child2"));
        
        count = DOMTreeProcessing.countSameTagSiblings(parent.getFirstChild());
        Assert.assertEquals("Did not find the correct number of siblings, expecting 1"+
            "got "+count, 1, count);
        
        temp = document.createElementNS("","test");
        parent.insertBefore(temp, middleChild);
        count = DOMTreeProcessing.countSameTagSiblings(temp);
        Assert.assertEquals("Did not find the correct number of siblings, expecting 0"+
            " got "+count, 0, count);
        
        count = DOMTreeProcessing.countSameTagSiblings(parent.getLastChild());
        Assert.assertEquals("Did not find the correct number of siblings, expecting 2"+
            " got "+count, 2, count);
    }
    
    /** Test of getNodeValue method, of class siena.xml.DOMTreeProcessing. */
    public void testGetNodeValue() {        
        Node node = document.createAttribute("parent");

	System.out.println(" - Test: DOMTreeProcessing - getNodeValue method");

        node.setNodeValue("passed");
        
        Assert.assertEquals("Did not get the correct value from the text node", 
            "passed", DOMTreeProcessing.getNodeValue(node));

        node = document.createElementNS("","parent");
        node.appendChild(document.createTextNode("passed"));
        
        Assert.assertEquals("Did not get the correct value from the text node", 
            "passed", DOMTreeProcessing.getNodeValue(node));
        
        node = document.createElementNS("","parent");
        Assert.assertNull("Value returned for the node was not null when it should have been.",
            DOMTreeProcessing.getNodeValue(node));
    }   
}
