//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: EqualityConditionTest.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//

/*
 * EqualityConditionTest.java
 * JUnit based test
 *
 * Created on December 2, 2001, 9:29 PM
 */                

package siena.xml.tests;

import junit.framework.*;
import siena.xml.rules.EqualityCondition;
import org.w3c.dom.Node;
import org.apache.xerces.dom.CoreDocumentImpl;

/**
 *
 * @author unknown
 */                                
public class EqualityConditionTest extends TestCase {
    
    public EqualityConditionTest(java.lang.String testName) {
        super(testName);
    }        
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(EqualityConditionTest.class);        
        return suite;
    }
    
    /** 
     * Test of meetCondition method, of class siena.xml.rules.EqualityCondition. 
     */
    public void testMeetCondition() {
        EqualityCondition conditionTrue = null;
        EqualityCondition conditionFalse = null;
        org.w3c.dom.Element parent = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("parent", null);
        org.w3c.dom.Element child1 = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("test1", "true");
        org.w3c.dom.Element child2 = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("test2", null);
        org.w3c.dom.Element child3 = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("test3", null);
        org.w3c.dom.Element child4 = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("passed", "true");
        
        System.out.println(" - Test: EqualityCondition - meetCondition method");

        conditionTrue = new EqualityCondition("passed", true);        
        conditionFalse = new EqualityCondition("passed", false);
        assertTrue("Condition was true even though the arguement was null.", !conditionTrue.meetCondition(null));
        assertTrue("Condition was met even though the parent node's value was null.", !conditionTrue.meetCondition(parent));
        siena.xml.DOMTreeProcessing.setValue(parent, "passed");
        assertTrue("Condition was not met even though the parent node's value was correct.", conditionTrue.meetCondition(parent));
        assertTrue("Condition was met when the condition was for not equals and the parent's node value was equal to the condition", !conditionFalse.meetCondition(parent));
        child1.setAttribute("name", "passed");
        assertTrue("Condition was not met even though the child1 attribute node passed in was correct.", conditionTrue.meetCondition(child1.getAttributes().getNamedItem("name")));
        assertTrue("Condition was met even though the child1 attribute node passed in was equal to the condition when the condition was not equals.", !conditionFalse.meetCondition(child1.getAttributes().getNamedItem("name")));

        conditionTrue = new EqualityCondition("sibling passed", true);
        conditionFalse = new EqualityCondition("sibling passed", false);
        parent.appendChild(child1);
        parent.appendChild(child2);
        parent.appendChild(child3);        
        assertTrue("Condition was met even though the parent node did not have any siblings.", !conditionTrue.meetCondition(parent));
        assertTrue("Condition was met even though the siblings of the child1 node did not have the specified tag.", !conditionTrue.meetCondition(child1));
        parent.appendChild(child4);
        assertTrue("Condition was not met even though there were siblings of the node that have the specified tag.", conditionTrue.meetCondition(child1));
        assertTrue("Condition was met even when child4 was equal to the condition specified in the not euqals condition.", !conditionFalse.meetCondition(child1));

        conditionTrue = new EqualityCondition("sibling passed@name", true);
        conditionFalse = new EqualityCondition("sibling passed@name", false);
        assertTrue("The condition was true even though the child1 node did not have the correct name.", !conditionTrue.meetCondition(child1));        
        child4.setAttribute("name","passed");
        assertTrue("The condition was not met even though child4 meets the criteria.", conditionTrue.meetCondition(child1));                
        assertTrue("The condition was met even though child4 is equal to the condition specified in the not equals condition.", !conditionFalse.meetCondition(child1));                

        conditionTrue = new EqualityCondition("parent any@name", true);
        conditionFalse = new EqualityCondition("parent any@name", false);
        assertTrue("The condition was met even though parent does not meet the criteria.", !conditionTrue.meetCondition(child4));
        assertTrue("The condition was not met even though parent meets the criteria by not being equal to the condiiton.", conditionFalse.meetCondition(child4));
        parent.setAttribute("name","passed");
        assertTrue("The condition was not met even though parent meets the criteria.", conditionTrue.meetCondition(child4));
        assertTrue("The condition was met even though parent does not meet the criteria by not being equal to the condiiton.", !conditionFalse.meetCondition(child4));
        
        conditionTrue = new EqualityCondition("parent not", true);
        assertTrue("The condition was met even though parent does not meet the criteria.", !conditionTrue.meetCondition(child4));
        conditionTrue = new EqualityCondition("parent parent", true);
        assertTrue("The condition was not met even though parent does meet the criteria.", !conditionTrue.meetCondition(child4));
        
        conditionTrue = new EqualityCondition(1, true);
        assertTrue("Given a value of 1, the condition failed when comparing equality to 1.", conditionTrue.meetCondition("1"));
        assertTrue("Given a value of 0, the condition worked when comparing equality to 1.", !conditionTrue.meetCondition("0"));

        conditionTrue = new EqualityCondition(1.0, true);
        assertTrue("Given a value of 1.0, the condition failed when comparing equality to 1.0.", conditionTrue.meetCondition("1.0"));
        assertTrue("Given a value of 0.0, the condition worked when comparing equality to 1.0.", !conditionTrue.meetCondition("0.0"));

        conditionTrue = new EqualityCondition(1, false);
        assertTrue("Given a value of 1, the condition worked when comparing inequality to 1.", !conditionTrue.meetCondition("1"));
        assertTrue("Given a value of 0, the condition falied when comparing inequality to 1.", conditionTrue.meetCondition("0"));

        conditionTrue = new EqualityCondition(1.0, false);
        assertTrue("Given a value of 1.0, the condition worked when comparing inequality to 1.0.", !conditionTrue.meetCondition("1.0"));
        assertTrue("Given a value of 0.0, the condition failed when comparing inequality to 1.0.", conditionTrue.meetCondition("0.0"));
    }
}
