//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: FunctionPredicateTest.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//

/*
 * FunctionPredicateTest.java
 * JUnit based test
 *
 * Created on December 2, 2001, 9:30 PM
 */                

package siena.xml.tests;

import junit.framework.*;
import java.util.StringTokenizer;
import siena.xml.xpath.FunctionPredicate;
 
/**
 *
 * @author unknown
 */                                
public class FunctionPredicateTest extends TestCase {
    
    public FunctionPredicateTest(java.lang.String testName) {
        super(testName);
    }        
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(FunctionPredicateTest.class);
        
        return suite;
    }
    
    /** Test of isPredicateStringFunction method, of class siena.xml.xpath.FunctionPredicate. */
    public void testIsPredicateStringFunction() {
        System.out.println(" - Test: FunctionPredicate - isPredicateStringFunction method");

	FunctionPredicate predicate = new FunctionPredicate("substring(rob,name)");
	Assert.assertTrue("FunctionPredicate failed to recognize substring "+
                      "function.", predicate.isPredicateStringFunction());

	predicate = new FunctionPredicate("substring-after(name, rob)");
	Assert.assertTrue("FunctionPredicate failed to recognize substring-after "+
                      "function.", predicate.isPredicateStringFunction());

	predicate = new FunctionPredicate("substring-before(name, \"rob\")");
	Assert.assertTrue("FunctionPredicate failed to recognize substring-before "+
                      "function.", predicate.isPredicateStringFunction());

	predicate = new FunctionPredicate("concat(name, rob, newString)");
	Assert.assertTrue("FunctionPredicate failed to recognize concat function.",
                       predicate.isPredicateStringFunction());

	predicate = new FunctionPredicate("contains(name, \"rob\")");
	Assert.assertTrue("FunctionPredicate failed to recognize contains function",
                       predicate.isPredicateStringFunction());

	predicate = new FunctionPredicate("starts-with(name, rob)");
	Assert.assertTrue("FunctionPredicate failed to recognize starts-with "+
                      "function.", predicate.isPredicateStringFunction());

	predicate = new FunctionPredicate("string-length(name)");
	Assert.assertTrue("FunctionPredicate failed to recognize string-length "+
                      "function.", predicate.isPredicateStringFunction());
        
    }
    
    /** Test of getStringArg1 method, of class siena.xml.xpath.FunctionPredicate. */
    public void testGetStringArgAt() {
        System.out.println(" - Test: FunctionPredicate - getStringArgAt");

        FunctionPredicate predicate = 
            new FunctionPredicate("concat(\"rob\",name, value, \"passed\", failed)");

        Assert.assertEquals("FunctionPredicate failed to set the first string "+
                            "arguement.", "rob", predicate.getStringArgAt(0));
        Assert.assertEquals("FunctionPredicate failed to set the first string "+
                            "arguement.", "name", predicate.getStringArgAt(1));
        Assert.assertEquals("FunctionPredicate failed to set the first string "+
                            "arguement.", "value", predicate.getStringArgAt(2));
        Assert.assertEquals("FunctionPredicate failed to set the first string "+
                            "arguement.", "passed", predicate.getStringArgAt(3));
        Assert.assertEquals("FunctionPredicate failed to set the first string "+
                            "arguement.", "failed", predicate.getStringArgAt(4));
    }

    /** Test of isArg1QuotedString method, of class siena.xml.xpath.FunctionPredicate. */
    public void testIsArgAQuotedString() {
        System.out.println(" - Test: FunctionPredicate isArgAQuotedString");

        FunctionPredicate predicate = 
            new FunctionPredicate("substring(\"rob\",name)");

        Assert.assertTrue("FunctionPredicate failed to recognize the quoted "+
                "String for arguement 1.", 
                predicate.isArgAQuotedString(0));

        predicate = new FunctionPredicate("substring(name, \"rob\")");
        Assert.assertTrue("FunctionPredicate recognized a quoted String for "+
                "arguement 1 when it should not of.", 
                !(predicate.isArgAQuotedString(0)));
    }

    /** Test of getFunctionName method, of class siena.xml.xpath.FunctionPredicate. */
    public void testGetFunctionName() {
        System.out.println(" - Test: FunctionPredicate getFunctionName");
        FunctionPredicate predicate = new FunctionPredicate("passed()");

        Assert.assertEquals("FunctionPredicate did not correctly identify "+
                "the name of the function.", "passed", 
                predicate.getFunctionName());
    }

    /** 
     * Test of getNumberOfArgs method, of class 
     * siena.xml.xpath.FunctionPredicatee 
     */

    public void testGetNumberOfArgs() {
        System.out.println(" - Test: FunctionPredicate - getNumberOfArgs method");
        FunctionPredicate predicate = new FunctionPredicate("string-length(passed)");
        Assert.assertEquals("FunctionPredicate miscounted the number of arguements.", 1, predicate.getNumberOfArgs());
        predicate = new FunctionPredicate("starts-with(fail,\"passed\")");
        Assert.assertEquals("FunctionPredicate miscounted the number of arguements.", 2, predicate.getNumberOfArgs());
        predicate = new FunctionPredicate("concat(name,value,\"passed\")");
        Assert.assertEquals("FunctionPredicate miscounted the number of arguements.", 3, predicate.getNumberOfArgs());
    }
}
