//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: PredicateTest.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//

/*
 * PredicateTest.java
 * JUnit based test
 *
 * Created on December 2, 2001, 9:30 PM
 */                

package siena.xml.tests;

import siena.xml.xpath.*;
import junit.framework.*;

/**
 *
 * @author unknown
 */                                
public class PredicateTest extends TestCase {
    
    public PredicateTest(java.lang.String testName) {
        super(testName);
    }        
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(PredicateTest.class);
        
        return suite;
    }
    
    /** Test of getType method, of class siena.xml.xpath.Predicate. */
    public void testGetType() {
        Predicate predicate = null;
        
        System.out.println(" - Test: Predicate - getType method");
        
        predicate = new FunctionPredicate("substring(name,\"rob\")");
        assertEquals("Wrong type was recieved for the FunctionPredicate.", Predicate.FUNCTION, predicate.getType());
        predicate = new EqualityPredicate("test","test");
        assertEquals("Wrong type was recieved for the EqualityPredicate.", Predicate.EQUALITY, predicate.getType());
        predicate = new PositionPredicate("last()");
        assertEquals("Wrong type was recieved for the PositionPredicate.", Predicate.POSITION, predicate.getType());
        predicate = new CompoundPredicate("[test = 0 and test > 1]");
        assertEquals("Wrong type was recieved for the CompoundPredicate.", Predicate.COMPOUND, predicate.getType());
        predicate = new ComparisonPredicate("test > 10");
        assertEquals("Wrong type was recieved for the ComparisonPredicate.", Predicate.COMPARE, predicate.getType());
        
    }
    
    /** Test of buildPredicate method, of class siena.xml.xpath.Predicate. */
    public void testBuildPredicate() {
        Predicate predicate = null;
        
        System.out.println(" - Test: Predicate - buildPredicate method");
        
        predicate = Predicate.buildPredicate("substring(name,\"rob\")");
        assertEquals("Wrong type was built for the FunctionPredicate.", Predicate.FUNCTION, predicate.getType());
        predicate = Predicate.buildPredicate("test = \"test\"");
        assertEquals("Wrong type was build for the EqualityPredicate.", Predicate.EQUALITY, predicate.getType());
        predicate = Predicate.buildPredicate("last()");
        assertEquals("Wrong type was build for the PositionPredicate.", Predicate.POSITION, predicate.getType());
        predicate = Predicate.buildPredicate("[test = 0 and test > 1]");
        assertEquals("Wrong type was built for the CompoundPredicate.", Predicate.COMPOUND, predicate.getType());
        predicate = Predicate.buildPredicate("test > 10");
        assertEquals("Wrong type was built for the ComparisonPredicate.", Predicate.COMPARE, predicate.getType());        
    }
}
