//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: RuleTest.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//

/*
 * RuleTest.java
 * JUnit based test
 *
 * Created on December 2, 2001, 9:29 PM
 */                

package siena.xml.tests;

import junit.framework.*;
import org.w3c.dom.Node;
import siena.xml.rules.Rule;

/**
 *
 * @author unknown
 */                                
public class RuleTest extends TestCase {
    
    public RuleTest(java.lang.String testName) {
        super(testName);
    }        
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(RuleTest.class);
        
        return suite;
    }
    
    /** Test of getRule method, of class siena.xml.rules.Rule. */
    public void testGetAction() {
        Rule testRule = new Rule("test", "passed");
        
        System.out.println(" - Test: Rule - getAction method");
        
        assertEquals("The action returned from the rule was incorrect.", "passed", testRule.getAction());
    }
    
    /** Test of doesRuleApplyToNode method, of class siena.xml.rules.Rule. */
    public void testDoesRuleApplyToNode() {
        Rule testRule = new Rule("testNode", "passed");
        org.w3c.dom.Element testNode = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("testNode","passed");
        Node childNode = siena.xml.DOMTreeProcessing.createNode("child",null);
        Node grandchildNode = siena.xml.DOMTreeProcessing.createNode("grandchild",null);
        Node targetNode = siena.xml.DOMTreeProcessing.createNode("target","passed");
        java.util.Vector attributeTargets = new java.util.Vector();
        
        System.out.println(" - Test: Rule - doesRuleApplyToNode method");
        
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        assertTrue("For the testNode(testNode, pased) rule did not apply when it should have.", testRule.doesRuleApplyToNode(testNode));
        
        testNode = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("node","failed");
        assertTrue("For the testNode(node,failed) rule did apply when it should not have.", !testRule.doesRuleApplyToNode(testNode));

        testRule = new Rule("node@name", "passed");
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        testNode.setAttribute("name","true");
        assertTrue("For the testNode@name=true the rule did not apply when it should have.", testRule.doesRuleApplyToNode(testNode));
        testNode.removeAttribute("name");
        assertTrue("For the testNode(no attributes) the rule did apply when it should not have.", !testRule.doesRuleApplyToNode(testNode));
        attributeTargets.addElement("@name");
        attributeTargets.addElement("@type");
        attributeTargets.addElement("@test");
        testRule.setAttributeTargets(attributeTargets);
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));        
        assertTrue("For the testNode(no attributes) the rule(multiple attribute targets) did apply when it should not have.", !testRule.doesRuleApplyToNode(testNode));
        testNode.setAttribute("name","true");
        testNode.setAttribute("type","boolean");
        testNode.setAttribute("test","passed");
        assertTrue("For the testNode(@name,@type,@test) the rule(multiple attribute targets) did not apply when it should have.", testRule.doesRuleApplyToNode(testNode));        

        testRule = new Rule("parent/child/grandchild/target", "passed");
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        testNode = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("parent",null);
        grandchildNode.appendChild(targetNode);
        childNode.appendChild(grandchildNode);
        testNode.appendChild(childNode);
        assertTrue("The check for the Path targets failed.", testRule.doesRuleApplyToNode(testNode));
    }
        
    /** Test of getTarget method, of class siena.xml.rules.Rule. */
    public void testGetTarget() {
        Rule testRule = new Rule("target","passed");
        
        System.out.println(" - Test: Rule - getTarget method");
        
        assertEquals("The target returned from the rule was not correct.", "target", testRule.getTarget());
        
        testRule = new Rule("target@name","passed");
        assertEquals("The target returned from the rule(target@name) was not correct.", "target@name", testRule.getTarget());        
    }
    
    /** Test of setToAndRule method, of class siena.xml.rules.Rule. */
    public void testSetToAndRule() {
        Rule testRule = new Rule("testNode", "passed");
        org.w3c.dom.Element testNode = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("testNode","passed");
        java.util.Vector attributeTargets = new java.util.Vector();
        
        System.out.println(" - Test: Rule - setToAndRule method");
        
        testRule.setToAndRule();
        attributeTargets.addElement("@name");
        attributeTargets.addElement("@type");
        attributeTargets.addElement("@test");
        testRule.setAttributeTargets(attributeTargets);
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));        

        testNode.setAttribute("name","true");
        testNode.setAttribute("type","boolean");
        testNode.setAttribute("test","passed");
        assertTrue("For the testNode(@name,@type,@test) the rule(AND) did not apply when it should have.", testRule.doesRuleApplyToNode(testNode));        
        testNode.removeAttribute("test");
        assertTrue("For the testNode(@name,@type) the rule(AND) did apply when it should not have.", !testRule.doesRuleApplyToNode(testNode));        
    }
    
    /** Test of setToOrRule method, of class siena.xml.rules.Rule. */
    public void testSetToOrRule() {
        Rule testRule = new Rule("testNode", "passed");
        org.w3c.dom.Element testNode = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("testNode","passed");
        java.util.Vector attributeTargets = new java.util.Vector();
        
        System.out.println(" - Test: Rule - setToOrRule method");
        
        testRule.setToOrRule();
        attributeTargets.addElement("@name");
        attributeTargets.addElement("@type");
        attributeTargets.addElement("@test");
        testRule.setAttributeTargets(attributeTargets);
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));
        testRule.addCondition(new siena.xml.rules.ExistsCondition(true));        

        testNode.setAttribute("name","true");
        assertTrue("For the testNode(@name) the rule(OR) did not apply when it should have.", testRule.doesRuleApplyToNode(testNode));        
        testNode.setAttribute("type","true");
        assertTrue("For the testNode(@name,@type) the rule(OR) did not apply when it should have.", testRule.doesRuleApplyToNode(testNode));        
        testNode.setAttribute("test","true");
        assertTrue("For the testNode(@name,@type,@test) the rule(OR) did not apply when it should have.", testRule.doesRuleApplyToNode(testNode));        
        testNode.removeAttribute("name");
        testNode.removeAttribute("type");
        testNode.removeAttribute("test");
        assertTrue("For the testNode(no attributes) the rule(OR) did apply when it should not have.", !testRule.doesRuleApplyToNode(testNode));                
    }
    
    /** Test of getTargetTag method, of class siena.xml.rules.Rule. */
    public void testGetTargetTag() {
        Rule testRule = new Rule("target@tag","passed");
        
        System.out.println(" - Test: Rule - getTargetTag method");

        assertEquals("The target tag returned by the rule was not correct.", "target", testRule.getTargetTag());
    }
        
    /** Test of apply method, of class siena.xml.rules.Rule. */
    public void testApply() {
        Rule ignoreRule = new Rule("testNode","ignore");
        Rule pathRule = new Rule("testNode","path");
        Rule groupRule = new Rule("testNode","group:passed");
        Rule uniqueRule = new Rule("testNode","unique:passed");
        Rule basicRule = new Rule("testNode","passed");
        org.w3c.dom.Element testNode = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("testNode","value");
        
        System.out.println(" - Test: Rule - apply method");

        assertEquals("The ignore rule was not applied correctly.", "IGNORE", ignoreRule.apply(testNode));
        assertEquals("The path rule was not applied correctly.", "PATH", pathRule.apply(testNode));
        assertEquals("The basic rule was not applied correctly.", "passed", basicRule.apply(testNode));
        assertEquals("The group rule was not applied correctly.", "passed", groupRule.apply(testNode));
        assertEquals("The unique rule was not applied correctly.", "passed$testNode", uniqueRule.apply(testNode));        
        basicRule = new Rule("testNode","currentTag");
        testNode = (org.w3c.dom.Element)siena.xml.DOMTreeProcessing.createNode("testNode",null);
        testNode.setAttribute("name","true");
        assertEquals("The basic rule was not applied correctly when the testNode had the name attribute.", "true", basicRule.apply(testNode));
        uniqueRule = new Rule("testNode@type", "unique:currentTag");
        basicRule = new Rule("testNode@type", "currentTag");
        testNode.removeAttribute("name");
        testNode.setAttribute("type","noType");
        assertEquals("The basic rule was not applied correctly when the testNode had the type attribute.", "type", basicRule.apply(testNode));
        assertEquals("The unique rule was not applied correctly.", "currentTag$type", uniqueRule.apply(testNode));                
    }
}
