//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: StepTest.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//

/*
 * StepTest.java
 * JUnit based test
 *
 * Created on December 2, 2001, 9:30 PM
 */                

package siena.xml.tests;

import junit.framework.*;

/**
 *
 * @author unknown
 */                                
public class StepTest extends TestCase {
    
    public StepTest(java.lang.String testName) {
        super(testName);
    }        
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(StepTest.class);
        
        return suite;
    }
    
    /** Test of hasPredicate method, of class siena.xml.xpath.Step. */
    public void testHasPredicate() {
        siena.xml.xpath.Step step = null;
        
        System.out.println(" - Test: Step - hasPredicate method");
        
        step = new siena.xml.xpath.Step("name [substring(name,\"rob\")]");
        assertTrue("A function predicate was specified by step but it did not recognize it.", step.hasPredicate());
        step = new siena.xml.xpath.Step("name [name = \"rob\"]");
        assertTrue("An equality predicate was specified by step but it did not recognize it.", step.hasPredicate());
        step = new siena.xml.xpath.Step("name [value < 10]");
        assertTrue("A comparison predicate was specified by step but it did not recognize it.", step.hasPredicate());
        step = new siena.xml.xpath.Step("name [last()]");
        assertTrue("A position predicate was specified by step but it did not recognize it.", step.hasPredicate());
        step = new siena.xml.xpath.Step("name [last() and name = \"bob\"]");        
        assertTrue("A compound predicate was specified by step but it did not recognize it.", step.hasPredicate());
        step = new siena.xml.xpath.Step("name");
        assertTrue("A predicate was not specified but the step recognized one.", !step.hasPredicate());
    }
    
    /** Test of getAxis method, of class siena.xml.xpath.Step. */
    public void testGetAxis() {
        siena.xml.xpath.Step step = null;
        
        System.out.println(" - Test: Step - getAxis method");
        
        step = new siena.xml.xpath.Step("child::name [substring(name,\"rob\")]");
        assertEquals("The tree axis for the step is incorrect.", "child", step.getAxis());
        step = new siena.xml.xpath.Step("name [substring(name,\"rob\")]");
        assertNull("The tree axis did not exist but the step said there was one.", step.getAxis());        
    }
    
    /** Test of getNodeTest method, of class siena.xml.xpath.Step. */
    public void testGetNodeTest() {
        siena.xml.xpath.Step step = null;
        
        System.out.println(" - Test: Step - getNodeTest method");
        
        step = new siena.xml.xpath.Step("text()");
        assertEquals("The node test function for the step is incorrect.", "text()", step.getNodeTest());
        step = new siena.xml.xpath.Step("name [substring(name,\"rob\")]");
        assertEquals("The node test for the the step is incorrect.", "name", step.getNodeTest());        
    }
    
    /** Test of getPredicate method, of class siena.xml.xpath.Step. */
    public void testGetPredicate() {
        siena.xml.xpath.Step step = null;
        
        System.out.println(" - Test: Step - getPredicate method");
        
        step = new siena.xml.xpath.Step("name [substring(name,\"rob\")]");
        assertEquals("A function predicate was specified by step but it did not recognize it.", siena.xml.xpath.Predicate.FUNCTION, step.getPredicate().getType());
        step = new siena.xml.xpath.Step("name [name = \"rob\"]");
        assertEquals("A function predicate was specified by step but it did not recognize it.", siena.xml.xpath.Predicate.EQUALITY, step.getPredicate().getType());
        step = new siena.xml.xpath.Step("name [value < 10]");
        assertEquals("A function predicate was specified by step but it did not recognize it.", siena.xml.xpath.Predicate.COMPARE, step.getPredicate().getType());
        step = new siena.xml.xpath.Step("name [last()]");
        assertEquals("A function predicate was specified by step but it did not recognize it.", siena.xml.xpath.Predicate.POSITION, step.getPredicate().getType());
        step = new siena.xml.xpath.Step("name [last() and name = \"bob\"]");        
        assertEquals("A function predicate was specified by step but it did not recognize it.", siena.xml.xpath.Predicate.COMPOUND, step.getPredicate().getType());
        step = new siena.xml.xpath.Step("name");
        assertNull("A predicate was returned but one was not specified.", step.getPredicate());
    }
    
    /** Test of isNodeTestAFunction method, of class siena.xml.xpath.Step. */
    public void testIsNodeTestAFunction() {
        siena.xml.xpath.Step step = null;
        
        System.out.println(" - Test: Step - isNodeTestAFunction method");
        
        step = new siena.xml.xpath.Step("text()");
        assertTrue("The step did not recognize the function for the node test.", step.isNodeTestAFunction());
        step = new siena.xml.xpath.Step("name [substring(name,\"rob\")]");
        assertTrue("The step recognized a function for the node test when there was not one.", !step.isNodeTestAFunction());        
    }
}
